@@ -1,6 +1,5 @@
 import logging
-import asyncio
-import pprint
+
 from ...abc.source import Source
 
 #
@@ -9,6 +8,7 @@ L = logging.getLogger(__name__)
 
 #
 
+
 class WebServiceSource(Source):
 	'''
 This source is to be integrated into aiohttp.web as a 'View'.
