@@ -1,6 +1,7 @@
 from .connection import KafkaConnection
 from .source import KafkaSource
 from .sink import KafkaSink
+from .batchsink import KafkaBatchSink
 from .keyfilter import KafkaKeyFilter
 
 __all__ = [
@@ -8,4 +9,5 @@ __all__ = [
 	"KafkaSource",
 	"KafkaSink",
 	"KafkaKeyFilter",
+	"KafkaBatchSink",
 ]
